@@ -32,6 +32,7 @@
 # Copyright 2024 Eduardo Ramírez <edu.rh90@gmail.com>                          #
 # Copyright 2024 Enrico Minack <github@enrico.minack.dev>                      #
 # Copyright 2024 Oskar Jansson <56458534+janssonoskar@users.noreply.github.com>#
+# Copyright 2025 Enrico Minack <github@enrico.minack.dev>                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -762,11 +763,13 @@ class AuthenticatedUser(Framework.TestCase):
         self.assertEqual(invitation.permissions, "write")
         created_at = datetime(2019, 6, 27, 11, 47, tzinfo=timezone.utc)
         self.assertEqual(invitation.created_at, created_at)
+        self.assertEqual(invitation.expired, True)
         self.assertEqual(
             invitation.url,
             "https://api.github.com/user/repository_invitations/17285388",
         )
         self.assertEqual(invitation.html_url, "https://github.com/jacquev6/PyGithub/invitations")
+        self.assertEqual(invitation.node_id, "MDIwOlJlcG9zaXRvcnlJbnZpdGF0aW9uMTcyODUzODg=")
         self.assertEqual(invitation.repository.name, "PyGithub")
         self.assertEqual(invitation.invitee.login, "foobar-test1")
         self.assertEqual(invitation.inviter.login, "jacquev6")
