@@ -5,6 +5,8 @@
 # Copyright 2023 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
 # Copyright 2023 Trim21 <trim21.me@gmail.com>                                  #
 # Copyright 2024 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2025 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2025 Timothy Klopotoski <tklopotoski@ebsco.com>                    #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -66,6 +68,9 @@ class Requester(Framework.TestCase):
             pool_size=5,
             seconds_between_requests=1.2,
             seconds_between_writes=3.4,
+            # v3: this should not be the default value, so if this has been changed in v3,
+            # change it here is well
+            lazy=True,
         )
         kwargs = requester.kwargs
 
@@ -84,6 +89,7 @@ class Requester(Framework.TestCase):
                 pool_size=5,
                 seconds_between_requests=1.2,
                 seconds_between_writes=3.4,
+                lazy=True,
             ),
         )
 
@@ -116,6 +122,9 @@ class Requester(Framework.TestCase):
             pool_size=5,
             seconds_between_requests=1.2,
             seconds_between_writes=3.4,
+            # v3: this should not be the default value, so if this has been changed in v3,
+            # change it here is well
+            lazy=True,
         )
 
         # create a copy with different auth
@@ -136,6 +145,7 @@ class Requester(Framework.TestCase):
                 pool_size=5,
                 seconds_between_requests=1.2,
                 seconds_between_writes=3.4,
+                lazy=True,
             ),
         )
 
@@ -283,8 +293,12 @@ class Requester(Framework.TestCase):
         for message in self.OtherErrors + self.PrimaryRateLimitErrors:
             self.assertFalse(github.Requester.Requester.isSecondaryRateLimitError(message), message)
 
-    def assertException(self, exception, exception_type, status, data, headers, string):
+    def assertException(self, exception, exception_type, message, status, data, headers, string):
         self.assertIsInstance(exception, exception_type)
+        if message is None:
+            self.assertIsNone(exception.message)
+        else:
+            self.assertEqual(exception.message, message)
         self.assertEqual(exception.status, status)
         if data is None:
             self.assertIsNone(exception.data)
@@ -298,6 +312,7 @@ class Requester(Framework.TestCase):
         self.assertException(
             exc,
             github.BadCredentialsException,
+            None,
             401,
             {"message": "Bad credentials"},
             {"header": "value"},
@@ -316,6 +331,7 @@ class Requester(Framework.TestCase):
         self.assertException(
             exc,
             github.TwoFactorException,
+            None,
             401,
             {
                 "message": "Must specify two-factor authentication OTP code.",
@@ -334,6 +350,7 @@ class Requester(Framework.TestCase):
         self.assertException(
             exc,
             github.BadUserAgentException,
+            None,
             403,
             {"message": "Missing or invalid User Agent string"},
             {"header": "value"},
@@ -347,6 +364,7 @@ class Requester(Framework.TestCase):
                 self.assertException(
                     exc,
                     github.RateLimitExceededException,
+                    None,
                     403,
                     {"message": message},
                     {"header": "value"},
@@ -358,12 +376,27 @@ class Requester(Framework.TestCase):
         self.assertException(
             exc,
             github.UnknownObjectException,
+            None,
             404,
             {"message": "Not Found"},
             {"header": "value"},
             '404 {"message": "Not Found"}',
         )
 
+    def testShouldCreateUnknownObjectException2(self):
+        exc = self.g._Github__requester.createException(
+            404, {"header": "value"}, {"message": "No object found for the path some-nonexistent-file"}
+        )
+        self.assertException(
+            exc,
+            github.UnknownObjectException,
+            None,
+            404,
+            {"message": "No object found for the path some-nonexistent-file"},
+            {"header": "value"},
+            '404 {"message": "No object found for the path some-nonexistent-file"}',
+        )
+
     def testShouldCreateGithubException(self):
         for status in range(400, 600):
             with self.subTest(status=status):
@@ -373,23 +406,24 @@ class Requester(Framework.TestCase):
                 self.assertException(
                     exc,
                     github.GithubException,
+                    "Something unknown",
                     status,
                     {"message": "Something unknown"},
                     {"header": "value"},
-                    f'{status} {{"message": "Something unknown"}}',
+                    f'Something unknown: {status} {{"message": "Something unknown"}}',
                 )
 
     def testShouldCreateExceptionWithoutMessage(self):
         for status in range(400, 600):
             with self.subTest(status=status):
                 exc = self.g._Github__requester.createException(status, {}, {})
-                self.assertException(exc, github.GithubException, status, {}, {}, f"{status} {{}}")
+                self.assertException(exc, github.GithubException, None, status, {}, {}, f"{status} {{}}")
 
     def testShouldCreateExceptionWithoutOutput(self):
         for status in range(400, 600):
             with self.subTest(status=status):
                 exc = self.g._Github__requester.createException(status, {}, None)
-                self.assertException(exc, github.GithubException, status, None, {}, f"{status}")
+                self.assertException(exc, github.GithubException, None, status, None, {}, f"{status}")
 
 
 class RequesterThrottleTestCase(Framework.TestCase):
