@@ -16,6 +16,7 @@
 # Copyright 2023 Enrico Minack <github@enrico.minack.dev>                      #
 # Copyright 2024 Caleb McCombs <caleb@mccombalot.net>                          #
 # Copyright 2024 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2025 Enrico Minack <github@enrico.minack.dev>                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -35,31 +36,35 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import annotations
+
 from . import Framework
 
 
 class SecurityAndAnalysis(Framework.TestCase):
     def setUp(self):
         super().setUp()
-        self.repo = self.g.get_repo("transmission-web-control/transmission-web-control")
+        self.repo = self.g.get_repo("PyGithub/PyGithub")
         self.maxDiff = None
 
-    def testRepoSecurityAndAnalysisAttributes(self):
-        self.assertEqual(self.repo.security_and_analysis.advanced_security.status, "disabled")
-        self.assertEqual(self.repo.security_and_analysis.dependabot_security_updates.status, "disabled")
-        self.assertEqual(self.repo.security_and_analysis.secret_scanning.status, "disabled")
-        self.assertEqual(self.repo.security_and_analysis.secret_scanning_push_protection.status, "disabled")
-        self.assertEqual(self.repo.security_and_analysis.secret_scanning_non_provider_patterns.status, "disabled")
-        self.assertEqual(self.repo.security_and_analysis.secret_scanning_validity_checks.status, "disabled")
+    def testAttributes(self):
+        security_and_analysis = self.repo.security_and_analysis
+        self.assertIsNone(security_and_analysis.advanced_security)
+        self.assertEqual(security_and_analysis.dependabot_security_updates.status, "enabled")
+        self.assertEqual(security_and_analysis.secret_scanning.status, "disabled")
+        self.assertIsNone(security_and_analysis.secret_scanning_ai_detection)
+        self.assertEqual(security_and_analysis.secret_scanning_push_protection.status, "disabled")
+        self.assertEqual(security_and_analysis.secret_scanning_non_provider_patterns.status, "disabled")
+        self.assertIsNone(security_and_analysis.secret_scanning_validity_checks)
 
-    def testRepoSecurityAndAnalysisRepresentation(self):
+    def testRepresentation(self):
         self.assertEqual(
             repr(self.repo.security_and_analysis),
             "SecurityAndAnalysis("
-            'secret_scanning_validity_checks="SecurityAndAnalysisFeature(status="disabled")", '
+            'secret_scanning_validity_checks="None", '
             'secret_scanning_push_protection="SecurityAndAnalysisFeature(status="disabled")", '
             'secret_scanning_non_provider_patterns="SecurityAndAnalysisFeature(status="disabled")", '
             'secret_scanning="SecurityAndAnalysisFeature(status="disabled")", '
-            'dependabot_security_updates="SecurityAndAnalysisFeature(status="disabled")", '
-            'advanced_security="SecurityAndAnalysisFeature(status="disabled")")',
+            'dependabot_security_updates="SecurityAndAnalysisFeature(status="enabled")", '
+            'advanced_security="None")',
         )
